
@extends('layouts.app')

@section('content')
<div class="container-fluid py-4">
    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-header border-0 bg-transparent">
                    <div class="d-flex justify-content-between">
                        <h5 class="mb-0">User Management</h5>
                        <a href="{{ route('user-management.create') }}" class="btn btn-primary">Add User</a>
                    </div>
                </div>
                <div class="card-body">
                    @if (session('success'))
                        <div class="alert alert-success">{{ session('success') }}</div>
                    @endif
                    @if (session('error'))
                        <div class="alert alert-danger">{{ session('error') }}</div>
                    @endif
                    <form id="batchDeleteForm" action="{{ route('user-management.batchDelete') }}" method="POST">
                        @csrf
                        @method('DELETE')
                        <div class="mb-3">
                            <button type="submit" class="btn btn-danger" onclick="return confirm('Are you sure you want to delete selected users?')">Delete Selected</button>
                        </div>
                        <table class="table table-bordered">
                            <thead>
                                <tr>
                                    <th><input type="checkbox" id="selectAll"></th>
                                    <th>Username</th>
                                    <th>Name</th>
                                    <th>Email</th>
                                    <th>Role</th>
                                    <th>Status</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse ($users as $user)
                                    <tr>
                                        <td><input type="checkbox" name="admin_uuid[]" value="{{ $user['admin_uuid'] }}"></td>
                                        <td>{{ $user['username'] }}</td>
                                        <td>{{ $user['firstName'] }} {{ $user['lastName'] }}</td>
                                        <td>{{ $user['email'] }}</td>
                                        <td>{{ $user['role'] }}</td>
                                        <td>{{ $user['status'] }}</td>
                                        <td>
                                            <a href="{{ route('user-management.show', $user['admin_uuid']) }}" class="btn btn-sm btn-info">View</a>
                                            <a href="{{ route('user-management.edit', $user['admin_uuid']) }}" class="btn btn-sm btn-primary">Edit</a>
                                            <form action="{{ route('user-management.destroy', $user['admin_uuid']) }}" method="POST" style="display:inline;" onsubmit="return confirm('Are you sure you want to delete this user?');">
                                                @csrf
                                                @method('DELETE')
                                                <button type="submit" class="btn btn-sm btn-danger">Delete</button>
                                            </form>
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td colspan="7" class="text-center">No users found.</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
@section('scripts')
<script>
    document.getElementById('selectAll').addEventListener('change', function() {
        let checkboxes = document.querySelectorAll('input[name="admin_uuid[]"]');
        checkboxes.forEach(checkbox => checkbox.checked = this.checked);
    });
</script>
@endsection
